@@ -5,7 +5,7 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at https://mozilla.org/MPL/2.0/.
 from accounts.get_accounts import GetAccounts
-from wallet.wallet import Address
+from wallet.wallet_import import Address
 
 
 def GetBalance(block, user):
