@@ -4,8 +4,6 @@
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at https://mozilla.org/MPL/2.0/.
-
-
 from transactions.get_my_transaction import GetMyTransaction
 
 
@@ -15,5 +13,7 @@ def PrintTransactions():
     """
 
     print("\n")
-    print(*[i.__dict__ for i in GetMyTransaction()], sep = "\n\n")
+    print(*[(str(i[0].__dict__) + " | " + str(i[1]))
+            for i in GetMyTransaction()],
+          sep="\n\n")
     print("\n")
