@@ -12,10 +12,6 @@ from transactions.change_transaction_fee import ChangeTransactionFee
 from transactions.check_transaction import CheckTransaction
 from transactions.propagating_the_tx import PropagatingtheTX
 from transactions.transaction import Transaction
-from transactions.tx_already_got import TXAlreadyGot
-from wallet.wallet import Ecdsa
-from wallet.wallet import PublicKey
-from wallet.wallet import Signature
 
 
 def SendTransactiontoTheBlock(
@@ -45,7 +41,6 @@ def SendTransactiontoTheBlock(
         transaction_fee=transaction_fee,
         time_of_transaction=transaction_time,
     )
-    print(the_tx.dump_json())
     checking = CheckTransaction(block, the_tx)
 
     if checking:
