@@ -6,7 +6,10 @@
 # file, You can obtain one at https://mozilla.org/MPL/2.0/.
 
 
-from wallet.wallet import Wallet_Import, get_saved_wallet, Wallet_Delete
+from wallet.wallet_import import wallet_import
+from wallet.get_saved_wallet import get_saved_wallet
+
+from wallet.wallet_delete import wallet_delete
 
 
 from lib.settings_system import the_settings, change_wallet
@@ -19,10 +22,10 @@ def delete_current_wallet():
 
     if not the_settings()["wallet"] == 0:
         saved_wallets = get_saved_wallet()
-        selected_wallet_pubkey = Wallet_Import(int(the_settings()["wallet"]), 0)
+        selected_wallet_pubkey = wallet_import(int(the_settings()["wallet"]), 0)
         for each_wallet in saved_wallets:
             if selected_wallet_pubkey == saved_wallets[each_wallet]["publickey"]:
                 change_wallet(0)
-                Wallet_Delete(each_wallet)
+                wallet_delete(each_wallet)
     else:
         print("First wallet cannot be deleted.")
