@@ -6,7 +6,8 @@
 # file, You can obtain one at https://mozilla.org/MPL/2.0/.
 
 
-from wallet.wallet import Wallet_Import, get_saved_wallet
+from wallet.wallet_import import wallet_import
+from wallet.get_saved_wallet import get_saved_wallet
 
 from lib.mixlib import menu_maker
 from lib.settings_system import the_settings
@@ -23,7 +24,7 @@ def print_wallets():
     result = []
     for wallet in all_wallets:
         number = all_wallets.index(wallet)
-        address = Wallet_Import(all_wallets.index(wallet), 3)
+        address = wallet_import(all_wallets.index(wallet), 3)
         if not current_wallet == number:
             text = menu_maker(menu_number=number, menu_text=address)
             print(text)
