@@ -6,7 +6,7 @@
 # file, You can obtain one at https://mozilla.org/MPL/2.0/.
 
 
-from wallet.wallet import get_saved_wallet
+from wallet.get_saved_wallet import get_saved_wallet
 
 from wallet.print_wallets import print_wallets
 
